/** \file workspace.h	Interface to workspace module.
 * \author Darryl Luff
 * \ingroup gui	*/
/* GtkSQL -- an interactive graphical query tool for PostgreSQL
 * Copyright (C) 2002-2003  Darryl Luff
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * ==========================================================================
 *
 * Workspace handling. The workspace will include the database connection
 * parameters, the currently open queries, and possibly the gui configuration?
 * Currently only contains the database connection items.
 */

#ifndef __WORKSPACE_H
#define __WORKSPACE_H
#include <gtk/gtk.h>

/** Toolbar format options.	*/
enum ToolbarOptions {
	TOOLBAR_ICONS = 1,		/**< Display icons only.	*/
	TOOLBAR_TEXT = 2,		/**< Display text only.	*/
	TOOLBAR_BOTH = 3		/**< Display both text and icons.	*/
};

/** Get the change state of the workspace.	*/
int ws_get_changed(void);

/** Get the toolbar configuration.	*/
gint ws_get_toolbarconf(void);

/** Initialise the workspace.	*/
void ws_init();

/** Load a workspace from a file.	*/
void ws_load_file(char *fname);

/** Save the workspace to a file.	*/
int ws_save_file(char *fname);

/** Set the toolbar configuration.	*/
void ws_set_toolbarconf(gint tbconf);

#endif
